﻿using Syncfusion.Windows.Diagram;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;

namespace PortRestriction
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        CustomPort port;
        CustomPort OldPort = new CustomPort();
        
        public MainWindow()
        {
            InitializeComponent();

            Node node1 = addNode(300, 300, Shapes.Rectangle, "Node", 100, 100);

            LineConnector connector1 = addConnector(new Point(400, 400), new Point(500, 500));
            LineConnector connector2 = addConnector(new Point(600, 400), new Point(700, 500));
     
            node1.Ports = new System.Collections.ObjectModel.ObservableCollection<ConnectionPort>();
            CustomPort port2 = addPort(node1, 50, 50, "ThirdPort");

     

            diagramView.ConnectorDragEnd += diagramView_ConnectorDragEnd;
        }

        private LineConnector addConnector(Point point1, Point point2)
        {
            LineConnector connector = new LineConnector()
            {
                StartPointPosition = point1,
                EndPointPosition = point2
            };
            diagramModel.Connections.Add(connector);
            return connector;
        }

        private void diagramView_ConnectorDragEnd(object sender, ConnDragEndRoutedEventArgs evtArgs)
        {
            LineConnector line = evtArgs.Connector;
            CustomPort outPort = line.ConnectionHeadPort as CustomPort;
            CustomPort inPort = line.ConnectionTailPort as CustomPort;

            if (outPort != null)
            {
                if (outPort.OutConnectors.Count == 0)
                    outPort.OutConnectors.Add(line);
                else
                {
                    line.ConnectionHeadPort = null;
                    line.HeadNode = null;
                }
            }

            if (inPort != null)
            {
                if (inPort.InConnectors.Count == 0)
                    inPort.InConnectors.Add(line);
                else
                {
                    line.ConnectionTailPort = null;
                    line.TailNode = null;
                }
            }
        }

        private CustomPort addPort(Node node, double p1, double p2, string text)
        {
            CustomPort port = new CustomPort();
            port.Style = this.Resources["style"] as Style;
            port.Top = p1;
            port.Left = p2;
            port.Width = 10;
            port.Height = 10;
            port.Node = node;
            port.PortStyle.Fill = new SolidColorBrush(Colors.Yellow);
            node.PortVisibility = PortVisibility.AlwaysVisible;
            node.Ports.Add(port);
            return port;
        }

        private Node addNode(double offsetx, double offsety, Shapes shape, String label, double width, double height)
        {
            Node node = new Node();
            node.NewZIndex = 50;
            node.OffsetX = offsetx;
            node.OffsetY = offsety;
            node.Shape = shape;
            node.Width = width;
            node.Height = height;
            diagramModel.Nodes.Add(node);
            return node;
        }
    }

    public class CustomPort : ConnectionPort
    {
        public CustomPort InPorts { get; set; }
        public CustomPort OutPorts { get; set; }
        public List<LineConnector> InConnectors { get; set; }
        public List<LineConnector> OutConnectors { get; set; }
        public CustomPort()
        {
            InConnectors = new List<LineConnector>();
            OutConnectors = new List<LineConnector>();
           
        }
        
    }
}

